package edu.chl.hajo.monopoly.core;

import java.util.Collection;

import java.util.List;

/**
 Class representing the overall game

 @author hajo

 */
public class Monopoly {

    // Application wide constants // TODO (possibly configurable )
    public static final int BALANCE = 1000;
    public static final int BONUS = 100;

    private final List<Player> players;
    private final Dices dices;
    private final Board board;
    private Player actual;

    // Players list should be random ordered, first player always set as actual!
    public Monopoly(List<Player> players, Board board, Dices dices) {
        this.dices = dices;
        this.board = board;
        this.players = players;
        actual = players.get(0);
        for (Player p : this.players) {
            p.setPosition(board.getStart());
        }
    }

    public void next() {
        int i = players.indexOf(actual);
        actual = players.get((i + 1) % players.size());
    }

    public void move() {
        Space oldPos = actual.getPosition();
        dices.roll();  // TODO GUI updated using observer
        Space newPos = board.getSpace(oldPos, dices.getTotal());
        actual.setPosition(newPos);
        
        // This alternat flow need no interaction, i.e. put it here
        if( board.passedGo(oldPos, newPos)){
            actual.income(BONUS);  // TODO GUI updated using observer
        }
        
    }

    // ------- Accessors -------------
    public Player getActual() {
        return actual;
    }

    public List<Player> getPlayers() {
        return players;
    }

}
