package xmlrpc;

import java.net.MalformedURLException;
import java.net.URL;

import org.apache.xmlrpc.XmlRpcException;
import org.apache.xmlrpc.client.XmlRpcClient;
import org.apache.xmlrpc.client.XmlRpcClientConfigImpl;

public class Sender extends XmlRpcClient {
		
	public Sender(String receiverURI) {
		XmlRpcClientConfigImpl config = new XmlRpcClientConfigImpl();
		try {
			config.setServerURL(new URL(receiverURI));
		} catch (MalformedURLException e) {
			e.printStackTrace();
		}
		this.setConfig(config);
	}
	
	/**
	 * Call a method on some (server) class. 
	 * @param classMethod Syntax: handler.method (for handler, see Receiver).
	 * @param params The parameters of the method to be executes wrapped in an Object array.
	 *		Must be in correct order with correct (primitive) types (identical to method parameter
	 *		list). Note: null's not supported. If any nulls in parameter array replace 
	 *		with "null" (string). Example: call("server.doIt", new Object[]{"aaa", 111, "null"});
	 *		
	 * @return The result of this method call as an Object (must cast to desired type).
	 */
	public Object call(String classMethod, Object[] params){
		Object o = null;
		try {
			o = super.execute(classMethod, params);
		} catch (XmlRpcException e) {
			e.printStackTrace();
			//throw new NetException(e.getMessage());
		}
		return o;
	}
}
